@@ -26,6 +26,23 @@ class Provider(BaseProvider):
     word_connector = ' '
     sentence_punctuation = '.'
 
+    def words(self, nb=3, ext_word_list=None, unique=False):
+        """
+        :returns: An array of random words. for example: ['Lorem', 'ipsum', 'dolor']
+
+        Keyword arguments:
+        :param nb: how many words to return
+        :param ext_word_list: a list of words you would like to have instead of
+            'Lorem ipsum'
+        :param unique: If True, the returned word list will contain unique words
+
+        :rtype: list
+        """
+        word_list = ext_word_list if ext_word_list else self.word_list
+        if unique:
+            return self.random_sample(word_list, length=nb)
+        return self.random_choices(word_list, length=nb)
+
     def word(self, ext_word_list=None):
         """
         :returns: A random word, eg: 'lorem'
@@ -35,22 +52,7 @@ class Provider(BaseProvider):
 
         :rtype: str
         """
-        if ext_word_list:
-            return self.random_element(ext_word_list)
-        return self.random_element(self.word_list)
-
-    def words(self, nb=3, ext_word_list=None):
-        """
-        :returns: An array of random words. for example: ['Lorem', 'ipsum', 'dolor']
-
-        Keyword arguments:
-        :param nb: how many words to return
-        :param ext_word_list: a list of words you would like to have instead of
-            'Lorem ipsum'
-
-        :rtype: list
-        """
-        return [self.word(ext_word_list) for _ in range(0, nb)]
+        return self.words(1, ext_word_list)[0]
 
     def sentence(self, nb_words=6, variable_nb_words=True, ext_word_list=None):
         """
