@@ -4,6 +4,7 @@ from collections import OrderedDict
 
 from .. import Provider as PersonProvider
 
+
 class Provider(PersonProvider):
     formats_male = OrderedDict((
         ('{{last_name_male}} {{first_name_male}} {{middle_name_male}}', 0.97),
@@ -93,7 +94,7 @@ class Provider(PersonProvider):
         'Олимпиада', 'Ольга', 'Пелагея', 'Полина', 'Прасковья', 'Раиса',
         'Регина', 'Светлана', 'Синклитикия', 'София', 'Таисия', 'Тамара',
         'Татьяна', 'Ульяна', 'Фаина', 'Феврония', 'Фёкла', 'Элеонора', 'Эмилия', 'Юлия'
-        )
+    )
 
     first_names = first_names_male + first_names_female
 
@@ -240,7 +241,7 @@ class Provider(PersonProvider):
         'Вадимовна', 'Васильевна', 'Владимировна', 'Валентиновна',
         'Вениаминовна', 'Владиславовна', 'Валериевна', 'Викторовна',
         'Вячеславовна', 'Геннадиевна', 'Георгиевна', 'Геннадьевна',
-        'Григорьевна', 'Даниловна', 'Дмитриевна', 'Евгеньевна', 'Егоровны',
+        'Григорьевна', 'Даниловна', 'Дмитриевна', 'Евгеньевна',
         'Егоровна', 'Ефимовна', 'Ждановна', 'Захаровна', 'Ивановна', 'Игоревна',
         'Ильинична', 'Кирилловна', 'Кузминична', 'Константиновна',
         'Кузьминична', 'Леонидовна', 'Леоновна', 'Львовна', 'Макаровна',
